netapp_ontap.models.security_association_ipsec_inbound API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_association_ipsec_inbound`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityAssociationIpsecInboundSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityAssociationIpsecInbound object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bytes: Size GET POST PATCH`

    Number of inbound bytes for the IPsec security association.

  `offload_bytes: Size GET POST PATCH`

    Number of inbound bytes processed by offload for the IPsec security association.

  `offload_packets: Size GET POST PATCH`

    Number of inbound packets processed by offload for the IPsec security association.

  `packets: Size GET POST PATCH`

    Number of inbound packets for the IPsec security association.

  `security_parameter_index: str GET POST PATCH`

    Inbound security parameter index for the IPSec security association.